@@ -22,7 +22,7 @@ import numpy as np
 import dask.array as da
 import xarray as xr
 from satpy.tests.reader_tests.test_hdf4_utils import FakeHDF4FileHandler
-from pyresample.geometry import AreaDefinition
+from pyresample.geometry import AreaDefinition, SwathDefinition
 
 import unittest
 from unittest import mock
@@ -95,10 +95,11 @@ class FakeHDF4FileHandlerPolar(FakeHDF4FileHandler):
         file_content['variable3'] = xr.DataArray(
             da.from_array(DEFAULT_FILE_DATA, chunks=4096).astype(np.byte),
             attrs={
+                'SCALED': 0,
                 '_FillValue': -128,
                 'flag_meanings': 'clear water supercooled mixed ice unknown',
                 'flag_values': [0, 1, 2, 3, 4, 5],
-                'units': '1',
+                'units': 'none',
             })
         file_content['variable3/shape'] = DEFAULT_FILE_SHAPE
 
@@ -113,10 +114,10 @@ class TestCLAVRXReaderPolar(unittest.TestCase):
     def setUp(self):
         """Wrap HDF4 file handler with our own fake handler."""
         from satpy._config import config_search_paths
-        from satpy.readers.clavrx import CLAVRXFileHandler
+        from satpy.readers.clavrx import CLAVRXHDF4FileHandler
         self.reader_configs = config_search_paths(os.path.join('readers', self.yaml_file))
         # http://stackoverflow.com/questions/12219967/how-to-mock-a-base-class-with-python-mock-library
-        self.p = mock.patch.object(CLAVRXFileHandler, '__bases__', (FakeHDF4FileHandlerPolar,))
+        self.p = mock.patch.object(CLAVRXHDF4FileHandler, '__bases__', (FakeHDF4FileHandlerPolar,))
         self.fake_handler = self.p.start()
         self.p.is_local = True
 
@@ -150,15 +151,15 @@ class TestCLAVRXReaderPolar(unittest.TestCase):
 
         # mimic the YAML file being configured for more datasets
         fake_dataset_info = [
-            (None, {'name': 'variable1', 'resolution': None, 'file_type': ['level2']}),
-            (True, {'name': 'variable2', 'resolution': 742, 'file_type': ['level2']}),
-            (True, {'name': 'variable2', 'resolution': 1, 'file_type': ['level2']}),
-            (None, {'name': 'variable2', 'resolution': 1, 'file_type': ['level2']}),
-            (None, {'name': '_fake1', 'file_type': ['level2']}),
+            (None, {'name': 'variable1', 'resolution': None, 'file_type': ['clavrx_hdf4']}),
+            (True, {'name': 'variable2', 'resolution': 742, 'file_type': ['clavrx_hdf4']}),
+            (True, {'name': 'variable2', 'resolution': 1, 'file_type': ['clavrx_hdf4']}),
+            (None, {'name': 'variable2', 'resolution': 1, 'file_type': ['clavrx_hdf4']}),
+            (None, {'name': '_fake1', 'file_type': ['clavrx_hdf4']}),
             (None, {'name': 'variable1', 'file_type': ['level_fake']}),
-            (True, {'name': 'variable3', 'file_type': ['level2']}),
+            (True, {'name': 'variable3', 'file_type': ['clavrx_hdf4']}),
         ]
-        new_ds_infos = list(r.file_handlers['level2'][0].available_datasets(
+        new_ds_infos = list(r.file_handlers['clavrx_hdf4'][0].available_datasets(
             fake_dataset_info))
         self.assertEqual(len(new_ds_infos), 9)
 
@@ -217,8 +218,12 @@ class TestCLAVRXReaderPolar(unittest.TestCase):
                            'variable3'])
         self.assertEqual(len(datasets), 3)
         for v in datasets.values():
-            assert 'calibration' not in v.attrs
             self.assertEqual(v.attrs['units'], '1')
+            self.assertEqual(v.attrs['platform_name'], 'npp')
+            self.assertEqual(v.attrs['sensor'], 'viirs')
+            self.assertIsInstance(v.attrs['area'], SwathDefinition)
+            self.assertEqual(v.attrs['area'].lons.attrs['rows_per_scan'], 16)
+            self.assertEqual(v.attrs['area'].lats.attrs['rows_per_scan'], 16)
         self.assertIsNotNone(datasets['variable3'].attrs.get('flag_meanings'))
 
 
@@ -287,6 +292,7 @@ class FakeHDF4FileHandlerGeo(FakeHDF4FileHandler):
             DEFAULT_FILE_DATA.astype(np.byte),
             dims=('y', 'x'),
             attrs={
+                'SCALED': 0,
                 '_FillValue': -128,
                 'flag_meanings': 'clear water supercooled mixed ice unknown',
                 'flag_values': [0, 1, 2, 3, 4, 5],
@@ -305,10 +311,10 @@ class TestCLAVRXReaderGeo(unittest.TestCase):
     def setUp(self):
         """Wrap HDF4 file handler with our own fake handler."""
         from satpy._config import config_search_paths
-        from satpy.readers.clavrx import CLAVRXFileHandler
+        from satpy.readers.clavrx import CLAVRXHDF4FileHandler
         self.reader_configs = config_search_paths(os.path.join('readers', self.yaml_file))
         # http://stackoverflow.com/questions/12219967/how-to-mock-a-base-class-with-python-mock-library
-        self.p = mock.patch.object(CLAVRXFileHandler, '__bases__', (FakeHDF4FileHandlerGeo,))
+        self.p = mock.patch.object(CLAVRXHDF4FileHandler, '__bases__', (FakeHDF4FileHandlerGeo,))
         self.fake_handler = self.p.start()
         self.p.is_local = True
 
@@ -368,10 +374,20 @@ class TestCLAVRXReaderGeo(unittest.TestCase):
             datasets = r.load(['variable1', 'variable2', 'variable3'])
         self.assertEqual(len(datasets), 3)
         for v in datasets.values():
-            assert 'calibration' not in v.attrs
+            self.assertNotIn('calibration', v.attrs)
             self.assertEqual(v.attrs['units'], '1')
             self.assertIsInstance(v.attrs['area'], AreaDefinition)
-        self.assertIsNotNone(datasets['variable3'].attrs.get('flag_meanings'))
+            if v.attrs.get("flag_values"):
+                self.assertIn('_FillValue', v.attrs)
+            else:
+                self.assertNotIn('_FillValue', v.attrs)
+            if v.attrs["name"] == 'variable1':
+                self.assertIsInstance(v.attrs["valid_range"], list)
+            else:
+                self.assertNotIn('valid_range', v.attrs)
+            if 'flag_values' in v.attrs:
+                self.assertTrue(np.issubdtype(v.dtype, np.integer))
+                self.assertIsNotNone(v.attrs.get('flag_meanings'))
 
     def test_load_all_new_donor(self):
         """Test loading all test datasets with new donor."""
@@ -401,7 +417,10 @@ class TestCLAVRXReaderGeo(unittest.TestCase):
             datasets = r.load(['variable1', 'variable2', 'variable3'])
         self.assertEqual(len(datasets), 3)
         for v in datasets.values():
-            assert 'calibration' not in v.attrs
+            self.assertNotIn('calibration', v.attrs)
             self.assertEqual(v.attrs['units'], '1')
             self.assertIsInstance(v.attrs['area'], AreaDefinition)
+            self.assertTrue(v.attrs['area'].is_geostationary)
+            self.assertEqual(v.attrs['platform_name'], 'himawari8')
+            self.assertEqual(v.attrs['sensor'], 'ahi')
         self.assertIsNotNone(datasets['variable3'].attrs.get('flag_meanings'))
