@@ -25,12 +25,12 @@ from datetime import datetime
 import numpy as np
 import xarray as xr
 
-AWIPS_FILE = "IMG_SX.M2.D17037.S1601.E1607.B0000001.WE.HR.ORB.nc"
+METOP_FILE = "IMG_SX.M2.D17037.S1601.E1607.B0000001.WE.HR.ORB.nc"
 NPP_MIRS_L2_SWATH = "NPR-MIRS-IMG_v11r6_npp_s201702061601000_e201702061607000_c202012201658410.nc"
 N20_MIRS_L2_SWATH = "NPR-MIRS-IMG_v11r4_n20_s201702061601000_e201702061607000_c202012201658410.nc"
 OTHER_MIRS_L2_SWATH = "NPR-MIRS-IMG_v11r4_gpm_s201702061601000_e201702061607000_c202010080001310.nc"
 
-EXAMPLE_FILES = [AWIPS_FILE, NPP_MIRS_L2_SWATH, OTHER_MIRS_L2_SWATH]
+EXAMPLE_FILES = [METOP_FILE, NPP_MIRS_L2_SWATH, OTHER_MIRS_L2_SWATH]
 
 N_CHANNEL = 3
 N_FOV = 96
@@ -50,6 +50,8 @@ POLO = xr.DataArray([2, 2, 3], dims='Channel',
 DS_IDS = ['RR', 'longitude', 'latitude']
 TEST_VARS = ['btemp_88v1', 'btemp_88v2',
              'btemp_22h', 'RR', 'Sfc_type']
+DEFAULT_UNITS = {'btemp_88v1': 'K', 'btemp_88v2': 'K',
+                 'btemp_22h': 'K', 'RR': 'mm/hr', 'Sfc_type': "1"}
 PLATFORM = {"M2": "metop-a", "NPP": "npp", "GPM": "gpm"}
 SENSOR = {"m2": "amsu-mhs", "npp": "atms", "gpm": "GPI"}
 
@@ -132,7 +134,7 @@ def _get_datasets_with_attributes(**kwargs):
 
     attrs = {'missing_value': -999.}
     ds = xr.Dataset(ds_vars, attrs=attrs)
-
+    ds = ds.assign_coords({"Freq": FREQ, "Latitude": latitude, "Longitude": longitude})
     return ds
 
 
@@ -173,13 +175,13 @@ def _get_datasets_with_less_attributes():
 
     attrs = {'missing_value': -999.}
     ds = xr.Dataset(ds_vars, attrs=attrs)
-
+    ds = ds.assign_coords({"Freq": FREQ, "Latitude": latitude, "Longitude": longitude})
     return ds
 
 
 def fake_open_dataset(filename, **kwargs):
     """Create a Dataset similar to reading an actual file with xarray.open_dataset."""
-    if filename == AWIPS_FILE:
+    if filename == METOP_FILE:
         return _get_datasets_with_less_attributes()
     return _get_datasets_with_attributes()
 
@@ -197,7 +199,7 @@ class TestMirsL2_NcReader:
     @pytest.mark.parametrize(
         ("filenames", "expected_loadables"),
         [
-            ([AWIPS_FILE], 1),
+            ([METOP_FILE], 1),
             ([NPP_MIRS_L2_SWATH], 1),
             ([OTHER_MIRS_L2_SWATH], 1),
         ]
@@ -217,7 +219,7 @@ class TestMirsL2_NcReader:
     @pytest.mark.parametrize(
         ("filenames", "expected_datasets"),
         [
-            ([AWIPS_FILE], DS_IDS),
+            ([METOP_FILE], DS_IDS),
             ([NPP_MIRS_L2_SWATH], DS_IDS),
             ([OTHER_MIRS_L2_SWATH], DS_IDS),
         ]
@@ -254,6 +256,11 @@ class TestMirsL2_NcReader:
         assert data_arr.data.min() >= test_valid_range[0]
         assert data_arr.data.max() <= test_valid_range[1]
 
+    @staticmethod
+    def _check_fill_value(data_arr, test_fill_value):
+        assert '_FillValue' not in data_arr.attrs
+        assert test_fill_value not in data_arr.data
+
     @staticmethod
     def _check_attrs(data_arr, platform_name):
         attrs = data_arr.attrs
@@ -266,12 +273,7 @@ class TestMirsL2_NcReader:
     @pytest.mark.parametrize(
         ("filenames", "loadable_ids", "platform_name"),
         [
-            ([AWIPS_FILE], TEST_VARS, "metop-a"),
-            ([NPP_MIRS_L2_SWATH], TEST_VARS, "npp"),
-            ([N20_MIRS_L2_SWATH], TEST_VARS, "noaa-20"),
-            ([OTHER_MIRS_L2_SWATH], TEST_VARS, "gpm"),
-
-            ([AWIPS_FILE], TEST_VARS, "metop-a"),
+            ([METOP_FILE], TEST_VARS, "metop-a"),
             ([NPP_MIRS_L2_SWATH], TEST_VARS, "npp"),
             ([N20_MIRS_L2_SWATH], TEST_VARS, "noaa-20"),
             ([OTHER_MIRS_L2_SWATH], TEST_VARS, "gpm"),
@@ -306,9 +308,13 @@ class TestMirsL2_NcReader:
                 if "valid_range" in input_fake_data.attrs:
                     valid_range = input_fake_data.attrs["valid_range"]
                     self._check_valid_range(data_arr, valid_range)
+                if "_FillValue" in input_fake_data.attrs:
+                    fill_value = input_fake_data.attrs["_FillValue"]
+                    self._check_fill_value(data_arr, fill_value)
 
                 sensor = data_arr.attrs['sensor']
                 if reader_kw.get('limb_correction', True) and sensor == 'atms':
                     fd.assert_called()
                 else:
                     fd.assert_not_called()
+                assert data_arr.attrs['units'] == DEFAULT_UNITS[var_name]
